@@ -199,3 +199,29 @@ def unpublish_from_public_bucket(input, sb_session_ex):
         raise Exception("Not status 200")
 
     return sb_resp.json()
+
+
+def upload_s3_files(input, sb_session_ex):
+    query = """
+                mutation uploadS3Files($input: UploadS3FilesInput!){
+                    uploadS3Files(input: $input){
+                      id 
+                    }
+                }
+            """
+
+    variables = {"input": input}
+
+    requests_session = requests.session()
+
+    sb_resp = requests_session.post(
+        sb_session_ex.get_graphql_url(),
+        headers=sb_session_ex.get_header(),
+        json={'query': query, 'variables': variables}
+    )
+
+    if sb_resp.status_code != 200 or 'errors' in sb_resp.json():
+        sb_session_ex.get_logger().error(sb_resp.json())
+        raise Exception("Not status 200")
+
+    return sb_resp.json()
